tlslite.errors.TLSLocalAlert

Package tlslite :: Module errors :: Class TLSLocalAlert |
[hide private]
[frames] | no frames]

# Class TLSLocalAlert

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            TLSError --+
                                       |
                                TLSAlert --+
                                           |
                                          TLSLocalAlert

A TLS alert has been signalled by the local implementation.

Instance Methods | [hide private]
__init__(self, alert, message=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__str__(self) "At least print out the Exception time for str(...). | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `TLSAlert` (private): `_descriptionStr`

Instance Variables | [hide private]
int | description Set to one of the constants in tlslite.constants.AlertDescription
int | level Set to one of the constants in tlslite.constants.AlertLevel
str | message Description of what went wrong.

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, alert, message=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
"At least print out the Exception time for str(...). Overrides: object.__str__ (inherited documentation)